import os
from pathlib import Path

from gi.repository import Gtk
from gi.repository import GdkPixbuf

from . import helpers
from .image_formats import IMAGES_FORMATS
from .translation import gettext as _
from .translation import format_string


class ImageStore(object):

    # fmt: off
    FIELDS = {
        "input_file":            {"id":  0, "label": "",                 "type": str,              "default": ""},
        "output_file":           {"id":  1, "label": "",                 "type": str,              "default": ""},
        "input_file_display":    {"id":  2, "label": _("Input Image"),   "type": str,              "default": ""},
        "output_file_display":   {"id":  3, "label": _("Output Image"),  "type": str,              "default": ""},
        "input_size":            {"id":  4, "label": "",                 "type": int,              "default": 0},
        "output_size":           {"id":  5, "label": "",                 "type": int,              "default": 0},
        "input_size_display":    {"id":  6, "label": _("Input Size"),    "type": str,              "default": ""},
        "output_size_display":   {"id":  7, "label": _("Output Size"),   "type": str,              "default": ""},
        "input_format":          {"id":  8, "label": _("Input Format"),  "type": str,              "default": ""},
        "output_format":         {"id":  9, "label": "",                 "type": str,              "default": "jpeg"},
        "output_format_display": {"id": 10, "label": _("Output Format"), "type": str,              "default": ""},
        "preview":               {"id": 11, "label": "",                 "type": GdkPixbuf.Pixbuf, "default": None},
        "separator":             {"id": 12, "label": "",                 "type": str,              "default": "➡️"},
        "status":                {"id": 13, "label": "",                 "type": int,              "default": 0},
        "status_display":        {"id": 14, "label": _("Status"),        "type": str,              "default": ""},
        "jpeg_quality":          {"id": 15, "label": "",                 "type": int,              "default": 90},
        "webp_quality":          {"id": 16, "label": "",                 "type": int,              "default": 90},
        "png_slow_optimization": {"id": 17, "label": "",                 "type": bool,             "default": False},
        "image_width":           {"id": 18, "label": "",                 "type": int,              "default": 0},
        "image_height":          {"id": 19, "label": "",                 "type": int,              "default": 0},
        "resize_enabled":        {"id": 20, "label": "",                 "type": bool,             "default": False},
        "resize_width":          {"id": 21, "label": "",                 "type": int,              "default": 1},
        "resize_height":         {"id": 22, "label": "",                 "type": int,              "default": 1},
        "output_pattern":        {"id": 23, "label": "",                 "type": str,              "default": ""},
        "use_output_pattern":    {"id": 24, "label": "",                 "type": bool,             "default": True},
    }
    # fmt: on

    STATUS_NONE = 0
    STATUS_PENDING = 1
    STATUS_IN_PROGRESS = 2
    STATUS_DONE = 3
    STATUS_CANCELED = 4

    gtk_list_store = None

    def __init__(self):
        store_fields = sorted(self.FIELDS.values(), key=lambda v: v["id"])
        self.gtk_list_store = Gtk.ListStore(*[f["type"] for f in store_fields])

    @property
    def length(self):
        """The length of the store."""
        return len(self.gtk_list_store)

    def append(self, **kwargs):
        """Appends a row to the image store.

        :param **kwargs: The columns key/value of the row.

        >>> image_store = ImageStore()
        >>> image_store.length
        0
        >>> image_store.append(
        ...     input_file="/tmp/foobar.png",
        ...     output_file="/tmp/foobar.opti.png",
        ... )
        >>> image_store.length
        1
        >>> image_store.append(foo="bar")
        Traceback (most recent call last):
            ...
        KeyError: "Invalid field 'foo'"
        """
        for key in kwargs:
            if key not in self.FIELDS:
                raise KeyError("Invalid field '%s'" % key)

        row = [None] * len(self.FIELDS)

        for key in self.FIELDS:
            field_info = self.FIELDS[key]
            row[field_info["id"]] = field_info["default"]

        iter_ = self.gtk_list_store.append(row)
        self.update(iter_, **kwargs)

    def clear(self):
        """Clears the store.

        >>> image_store = ImageStore()
        >>> image_store.append()
        >>> image_store.length
        1
        >>> image_store.clear()
        >>> image_store.length
        0
        """
        self.gtk_list_store.clear()

    def get(self, index):
        """Gets row data.

        :param int,gtk.TreeIter index: The index of the row.

        :rtype: dict
        :returns: The row data (e.g. ``{"field_name": "value"}``.

        >>> image_store = ImageStore()
        >>> image_store.append()
        >>> image_store.get(0)
        {...}
        >>> image_store.get(1)
        Traceback (most recent call last):
            ...
        IndexError: ...
        """
        row = self.gtk_list_store[index]
        result = {}

        for field_name, field_info in self.FIELDS.items():
            result[field_name] = row[field_info["id"]]

        return result

    def get_all(self):
        """Get all rows of the store.

        :rtype: generator

        >>> image_store = ImageStore()
        >>> image_store.get_all()
        <generator object ImageStore.get_all at ...>
        """
        for i in range(self.length):
            yield self.get(i)

    def remove(self, iter_):
        """Removes a row at given gtk.TreeIter from the store.

        :param gtk.TreeIter index: The iter of the row.
        """
        self.gtk_list_store.remove(iter_)

    def remove_at_index(self, index):
        """Removes a row at given index from the store.

        :param int index: The index of the row.

        >>> image_store = ImageStore()
        >>> image_store.append()
        >>> image_store.length
        1
        >>> image_store.remove_at_index(0)
        >>> image_store.length
        0
        >>> image_store.remove_at_index(0)
        Traceback (most recent call last):
            ...
        IndexError: ...
        """
        try:
            iter_ = self.gtk_list_store.get_iter(index)
        except ValueError as error:
            raise IndexError(error)
        self.remove(iter_)

    def update(self, index, **kwargs):
        """Updates a row.

        :param int,gtk.TreeIter index: The index of the row.
        :param **kwargs: The columns key/value of the row.

        >>> image_store = ImageStore()
        >>> image_store.append(
        ...     output_format="png",
        ...     output_file="aaa.png",
        ...     use_output_pattern=False,
        ... )
        >>> image_store.get(0)["output_file"]
        '...aaa.png'
        >>> image_store.update(0, output_file="bbb.png")
        >>> image_store.get(0)["output_file"]
        '...bbb.png'
        >>> image_store.update(0, foo="bar")
        Traceback (most recent call last):
            ...
        KeyError: "Invalid field 'foo'"
        >>> image_store.update(1, output_file="ccc.png")
        Traceback (most recent call last):
            ...
        IndexError: ...
        """
        _FORMATS_EXTS = {
            fid: fmt["exts"][0] for fid, fmt in IMAGES_FORMATS.items()
        }

        for key in kwargs:
            if key not in self.FIELDS:
                raise KeyError("Invalid field '%s'" % key)

        for key in kwargs:
            self._update_field(index, key, kwargs[key])

        if "input_file" in kwargs:
            path = Path(self.get(index)["input_file"])
            self._update_field(
                index,
                "input_file_display",
                path.name,
            )

        if (
            "output_format" in kwargs
            or "jpeg_quality" in kwargs
            or "webp_quality" in kwargs
            or "png_slow_optimization" in kwargs
        ):
            output_format = self.get(index)["output_format"]

            if output_format == "jpeg":
                text = "%s (%i %%)" % (
                    IMAGES_FORMATS["jpeg"]["display_name"],
                    self.get(index)["jpeg_quality"],
                )
                self._update_field(index, "output_format_display", text)
            elif output_format == "webp":
                text = "%s (%i %%)" % (
                    IMAGES_FORMATS["webp"]["display_name"],
                    self.get(index)["webp_quality"],
                )
                self._update_field(index, "output_format_display", text)
            elif output_format == "png":
                text = "%s%s" % (
                    IMAGES_FORMATS["png"]["display_name"],
                    (" (%s)" % "slow")
                    if self.get(index)["png_slow_optimization"]
                    else "",
                )
                self._update_field(index, "output_format_display", text)
            else:
                self._update_field(
                    index,
                    "output_format_display",
                    IMAGES_FORMATS[output_format]["display_name"],
                )

        if (
            "input_file" in kwargs
            or "output_file" in kwargs
            or "output_format" in kwargs
            or "output_pattern" in kwargs
            or "use_output_pattern" in kwargs
        ):
            output_pattern = self.get(index)["output_pattern"]
            output_format = self.get(index)["output_format"]
            output_ext = _FORMATS_EXTS[output_format]
            input_file = Path(self.get(index)["input_file"])
            filename_without_ext = str(input_file.name)[
                : -len(input_file.suffix)
            ]
            if self.get(index)["use_output_pattern"]:
                # fmt: off
                output_file = input_file.parent / output_pattern \
                    .replace("{FILENAME}", filename_without_ext) \
                    .replace("{EXT}", output_ext[1:])
                # fmt: on
            else:
                # Simply swap extension on custom paths
                output_file = Path(self.get(index)["output_file"]).with_suffix(
                    output_ext
                )
            self._update_field(
                index, "output_file", str(output_file.resolve())
            )

        if "image_width" in kwargs:
            self._update_field(index, "resize_width", kwargs["image_width"])

        if "image_height" in kwargs:
            self._update_field(index, "resize_height", kwargs["image_height"])

        if (
            "output_file" in kwargs
            or "output_format" in kwargs
            or "resize_enabled" in kwargs
            or "resize_width" in kwargs
            or "resize_height" in kwargs
            or "output_pattern" in kwargs
            or "use_output_pattern" in kwargs
        ):
            output_file = Path(self.get(index)["output_file"])
            input_file = Path(self.get(index)["input_file"])
            relative_path = os.path.relpath(
                output_file, start=input_file.parent
            )

            resize = ""
            if self.get(index)["resize_enabled"]:
                ratio = min(
                    self.get(index)["resize_width"]
                    / self.get(index)["image_width"],
                    self.get(index)["resize_height"]
                    / self.get(index)["image_height"],
                )
                if ratio < 1.0:
                    resize = " (↓ %i×%i px)" % (
                        self.get(index)["image_width"] * ratio,
                        self.get(index)["image_height"] * ratio,
                    )

            self._update_field(
                index,
                "output_file_display",
                relative_path + resize,
            )

        if "input_size" in kwargs:
            self._update_field(
                index,
                "input_size_display",
                helpers.human_readable_file_size(
                    self.get(index)["input_size"]
                ),
            )

        if "output_size" in kwargs:
            input_size = self.get(index)["input_size"]
            output_size = self.get(index)["output_size"]

            output_size_display = ""

            if output_size > 0:
                size_delta = -(100 - output_size / input_size * 100)
                output_size_display = "%s (%s%s %%)" % (
                    helpers.human_readable_file_size(output_size),
                    "+" if output_size > input_size else "",
                    format_string("%.1f", size_delta),
                )

            self._update_field(
                index,
                "output_size_display",
                output_size_display,
            )

        if "status" in kwargs:
            _STATUS = {
                0: "",
                1: "⏸️ %s" % _("Pending"),
                2: "🔄️ %s" % _("In progress"),
                3: "✅️ %s" % _("Done"),
                4: "⏹️ %s" % _("Canceled"),
            }
            self._update_field(
                index,
                "status_display",
                _STATUS[self.get(index)["status"]],
            )

    def reset_status(self, index):
        """Reset the status of the image at given index.

        :param int,gtk.TreeIter index: The index of the row.

        >>> image_store = ImageStore()
        >>> image_store.append(
        ...     status=ImageStore.STATUS_DONE,
        ...     input_size=1024,
        ...     output_size=1024,
        ... )
        >>> image_store.get(0)["status"]
        3
        >>> image_store.get(0)["output_size"]
        1024
        >>> image_store.get(0)["output_size_display"]
        '1...'
        >>> image_store.reset_status(0)
        >>> image_store.get(0)["status"]
        0
        >>> image_store.get(0)["output_size"]
        0
        >>> image_store.get(0)["output_size_display"]
        ''
        """
        self.update(
            index,
            status=ImageStore.STATUS_NONE,
            output_size=0,
        )

    def _update_field(self, index, field_name, value):
        row = self.gtk_list_store[index]
        row[self.FIELDS[field_name]["id"]] = value



"""
Supported image formats.

::

    "<format_id>": {             # Internal ID for the format
        "display_name: str,      # The name of the format as displayed in the UI
        "exts": [".ext"],        # Possible file extentions for the format (lowercase)
        "mimetype": str,         # Mimetype (e.g. "image/jpeg")
        "input": bool,           # Is the format supported as input
        "output": bool,          # Is the format supported as output
        "check_function": None,  # | A fonction to check if a file is in the given format
                                 # | Check function definition: "def check(format_id, filename)"
    },
"""

import pathlib
from .translation import gettext as _


IMAGES_FORMATS = {
    # ==== Formats supported as output ====
    "jpeg": {
        "display_name": "JPEG",
        "exts": [".jpg", ".jpeg"],
        "mimetype": "image/jpeg",
        "input": True,
        "output": True,
        "check_function": "_check_extention",
    },
    "png": {
        "display_name": "PNG",
        "exts": [".png"],
        "mimetype": "image/png",
        "input": True,
        "output": True,
        "check_function": "_check_extention",
    },
    "webp": {
        "display_name": "WebP",
        "exts": [".webp"],
        "mimetype": "image/webp",
        "input": True,
        "output": True,
        "check_function": "_check_extention",
    },
    "webpl": {
        "display_name": _("WebP (lossless)"),
        "exts": [".webp"],
        "mimetype": "image/webp",
        "input": True,
        "output": True,
        "check_function": "_check_nop",
    },
    # ==== Formats only supported as input ====
    "bmp": {
        "display_name": _("Windows Bitmap"),
        "exts": [".bmp", ".dib"],
        "mimetype": "image/bmp",
        "input": True,
        "output": False,
        "check_function": "_check_extention",
    },
    "eps": {
        "display_name": "EPS",
        "exts": [".eps"],
        "mimetype": "image/x-eps",
        "input": True,
        "output": False,
        "check_function": "_check_extention",
    },
    "gif": {
        "display_name": "GIF",
        "exts": [".gif"],
        "mimetype": "image/gif",
        "input": True,
        "output": False,
        "check_function": "_check_extention",
    },
    "icns": {
        "display_name": _("MacOS Icon (ICNS)"),
        "exts": [".icns"],
        "mimetype": "image/x-icns",
        "input": True,
        "output": False,
        "check_function": "_check_extention",
    },
    "ico": {
        "display_name": _("Windows Icon (ICO)"),
        "exts": [".ico"],
        "mimetype": "image/vnd.microsoft.icon",
        "input": True,
        "output": False,
        "check_function": "_check_extention",
    },
    "tga": {
        "display_name": "Truevision TGA",
        "exts": [".tga"],
        "mimetype": "image/x-tga",
        "input": True,
        "output": False,
        "check_function": "_check_extention",
    },
    "tiff": {
        "display_name": "TIFF",
        "exts": [".tiff", ".tif"],
        "mimetype": "image/tiff",
        "input": True,
        "output": False,
        "check_function": "_check_extention",
    },
    # ==== TODO ====
    # BLP
    # CUR
    # DCX
    # DDS
    # FLI, FLC
    # FPX
    # FTEX
    # GBR
    # GD
    # IM
    # IMT
    # IPTC/NAA
    # JPEG 2000
    # MCIDAS
    # MIC
    # MPO
    # MSP
    # PBM
    # PCD
    # PCX
    # PGM
    # PIXAR
    # PNM
    # PPM
    # PSD
    # SGI
    # SPIDER
    # WAL
    # WMF
    # XBM
    # XPM
}


def _check_extention(format_id, filename):
    """Check if the given file name matches the format extension.

    :param str format_id: The internal format identifier to check.
    :param str filename: The path of the file to check.

    :rtype: bool
    :return: whether or not the file name matches the format extensions.

    >>> _check_extention("jpeg", "test.jpg")
    True
    >>> _check_extention("jpeg", "test.jpeg")
    True
    >>> _check_extention("jpeg", "test.JPEG")
    True
    >>> _check_extention("png", "test.png")
    True
    >>> _check_extention("png", "test.jpg")
    False
    """
    exts = IMAGES_FORMATS[format_id]["exts"]
    return pathlib.Path(filename).suffix.lower() in exts


def _check_nop(format_id, filename):
    """Format checker that always returns False (used to disable a format).

    :param str format_id: The internal format identifier to check.
    :param str filename: The path of the file to check.

    :rtype: bool
    :return: Always returns ``False``.

    > _check_nop("foo", "bar")
    False
    """
    return False


def find_file_format(filename):
    """Finds the format of the given file.

    :param str filename: The path of the file.

    :rtype: str or None
    :return: The format_id for the given file name or ``None``.

    >>> find_file_format("test.jpeg")
    'jpeg'
    >>> find_file_format("test.png")
    'png'
    >>> find_file_format("test.foo")
    """
    for format_id in IMAGES_FORMATS:
        checker_function = globals()[
            IMAGES_FORMATS[format_id]["check_function"]
        ]
        if checker_function(format_id, filename):
            return format_id
    return None


def get_supported_input_format_mimetypes():
    return [fmt["mimetype"] for fmt in IMAGES_FORMATS.values() if fmt["input"]]


def get_supported_input_format_exts():
    return set(
        ext
        for fmt in IMAGES_FORMATS.values()
        if fmt["input"]
        for ext in fmt["exts"]
    )


def get_supported_output_format_ids():
    return [fid for fid, fmt in IMAGES_FORMATS.items() if fmt["output"]]


def get_supported_output_format_names():
    return [
        fmt["display_name"] for fmt in IMAGES_FORMATS.values() if fmt["output"]
    ]



from PIL import Image
from gi.repository import GLib
from gi.repository import Gio
from gi.repository import GdkPixbuf

from .translation import gettext as _
from .translation import format_string


def human_readable_file_size(size):
    """Returns human readable file size (e.g. "11.4 kiB").

    .. NOTE::

       This function do not supports size > 1024 GiB.

    :param int size: File size in Bytes.
    :rtype: str

    >>> human_readable_file_size(123)
    '123 Bytes'
    >>> human_readable_file_size(1024)
    '1.00 kiB'
    >>> human_readable_file_size(1024 * 1024)
    '1.00 MiB'
    >>> human_readable_file_size(1024 * 1024 * 1024)
    '1.00 GiB'
    >>> human_readable_file_size(1024 + 512)
    '1.50 kiB'
    """
    if size < 1024:
        return "%i %s" % (size, _("Bytes"))
    for u, d in [
        (_("kiB"), 1024 ** 1),
        (_("MiB"), 1024 ** 2),
        (_("GiB"), 1024 ** 3),
    ]:
        if size / d < 1024:
            return "%s %s" % (format_string("%.2f", size / d), u)
    return "∞"


def gvfs_uri_to_local_path(uri):
    """Get a local file path from a GVFS URI.

    :param str uri: A GVFS file URI.

    >>> gvfs_uri_to_local_path("file:///tmp")
    '/tmp'
    >>> gvfs_uri_to_local_path("file:///foo%20bar/baz.txt")
    '/foo bar/baz.txt'
    """
    gvfs = Gio.Vfs.get_default()
    return gvfs.get_file_for_uri(uri).get_path()


def open_image_from_path(path):
    """Open a PIL image from the given path.

    TODO: Handle JPEG rotation

    :param str path: The path of the image.

    :rtype: PIL.Image.Image
    """
    return Image.open(path)


def preview_gdk_pixbuf_from_image(image, size=64):
    """Returns a Gdk Pixbuf containing the preview the image at the given path.

    :param PIL.Image.Image image: the image.
    :param int size: The size of the preview (optional, default: ``64``).

    :rtype: GdkPixbuf.Pixbuff
    """
    EXIF_TAG_ORIENTATION = 274
    ORIENTATION_OPERATIONS = {
        1: [],
        2: [Image.FLIP_LEFT_RIGHT],
        3: [Image.ROTATE_180],
        4: [Image.FLIP_TOP_BOTTOM],
        5: [Image.FLIP_LEFT_RIGHT, Image.ROTATE_90],
        6: [Image.ROTATE_270],
        7: [Image.FLIP_LEFT_RIGHT, Image.ROTATE_270],
        8: [Image.ROTATE_90],
    }

    image_rgba = Image.new("RGBA", image.size)
    image_rgba.paste(image)
    image_rgba.thumbnail([size, size], Image.LANCZOS)

    # Handle JPEG orientation
    if image.format == "JPEG":
        exif = image.getexif()
        if EXIF_TAG_ORIENTATION in exif:
            orientation = exif[EXIF_TAG_ORIENTATION]
            for operation in ORIENTATION_OPERATIONS[orientation]:
                image_rgba = image_rgba.transpose(operation)

    # fmt: off
    pixbuf = GdkPixbuf.Pixbuf.new_from_bytes(
        GLib.Bytes.new(image_rgba.tobytes()),  # data
        GdkPixbuf.Colorspace.RGB,              # colorspace
        True,                                  # has alpha
        8,                                     # bits_per_sample
        *image_rgba.size,                      # width, height
        image_rgba.size[0] * 4,                # rowstride
    )
    # fmt: on

    image_rgba.close()

    return pixbuf



import functools
import multiprocessing
from concurrent.futures import ProcessPoolExecutor
from concurrent.futures._base import RUNNING


def _callable_wrapper(is_running, fn, *args, **kwargs):
    is_running.value = True
    fn(*args, **kwargs)
    is_running.value = False


def _future_running_override(future, is_running):
    return future._state == RUNNING and is_running.value


class StoppableProcessPoolExecutor(ProcessPoolExecutor):
    """A concurrent.futures.ProcessPoolExecutor that kills running processes on
    shutdown.

    This also fix the wrong running state of futures. See
    https://bugs.python.org/issue37276
    """

    def __init__(self, *args, **kwargs):
        self._state_manager = multiprocessing.Manager()
        ProcessPoolExecutor.__init__(self, *args, **kwargs)

    def shutdown(self, *args, **kwargs):
        processes = self._processes
        ProcessPoolExecutor.shutdown(self, *args, **kwargs)
        for pid, process in processes.items():
            process.kill()
        self._state_manager.shutdown()

    shutdown.__doc__ = ProcessPoolExecutor.shutdown.__doc__

    def submit(self, fn, *args, **kwargs):
        is_running = self._state_manager.Value(bool, False)
        future = ProcessPoolExecutor.submit(
            self,
            functools.partial(_callable_wrapper, is_running, fn),
            *args,
            **kwargs,
        )
        # Monkey patch future.running to return the real running state
        future.running = functools.partial(
            _future_running_override, future, is_running
        )
        return future

    submit.__doc__ = ProcessPoolExecutor.submit.__doc__



from gi.repository import Gtk
from gi.repository import GdkPixbuf

from . import APPLICATION_NAME
from . import VERSION
from . import data_helpers
from .translation import gettext as _


class AboutDialog(Gtk.AboutDialog):
    def __init__(self, parent=None):
        Gtk.AboutDialog.__init__(
            self,
            parent=parent,
            program_name=APPLICATION_NAME,
            comments=_(
                "A graphical interface to convert and optimize "
                "JPEG, PNG and WebP images (based on YOGA)"
            ),
            version=VERSION,
            copyright="Copyright (c) 2021 Fabien LOISON",
            website_label="yoga.flozz.org",
            website="https://yoga.flozz.org/",
            license_type=Gtk.License.GPL_3_0,
        )

        logo = GdkPixbuf.Pixbuf.new_from_file(
            data_helpers.find_data_path("images/icon_256.png")
        )
        self.set_logo(logo)

        self.set_artists(
            [
                "Katia ROBINSON (Wanadev)",
            ]
        )

        self.set_translator_credits(_("translator-credits"))



import os

from gi.repository import Gtk

from . import APPLICATION_ID
from . import data_helpers
from .translation import gtk_builder_translation_hack


class CustomPatternDialog(object):
    def __init__(self, initial_pattern="", parent_window=None):
        self._custom_pattern = None

        self._builder = Gtk.Builder()
        self._builder.set_translation_domain(APPLICATION_ID)
        self._builder.add_from_file(
            data_helpers.find_data_path("ui/custom-pattern-dialog.glade")
        )
        self._builder.connect_signals(self)

        self._dialog = self._builder.get_object("custom_pattern_dialog")
        self._entry = self._builder.get_object("custom_pattern_entry")
        self._entry.set_text(initial_pattern)

        self._dialog.set_transient_for(parent_window)

        # HACK: Translate the UI on Windows
        if os.name == "nt":
            gtk_builder_translation_hack(self._builder)

    def run(self):
        self._dialog.run()
        return self._custom_pattern

    def _on_cancel_button_cliqued(self, widget):
        self._dialog.destroy()

    def _on_apply_button_cliqued(self, widget):
        self._custom_pattern = self._entry.get_text()
        self._dialog.destroy()

    def _on_custom_pattern_dialog_response(self, widget, response_id):
        self._dialog.destroy()



#!/usr/bin/env python
# encoding: UTF-8

import os

from setuptools import setup, find_packages


long_description = ""
if os.path.isfile("README.rst"):
    long_description = open("README.rst", "r", encoding="UTF-8").read()


setup(
    name="yoga_image_optimizer",
    version="1.1.1",
    description="A graphical interface to convert and optimize JPEG, PNG and WebP images (based on YOGA)",
    url="https://github.com/flozz/yoga-image-optimizer",
    license="BSD-3-Clause",
    long_description=long_description,
    keywords="image jpeg png optimizer converter guetzli zopfli gui gtk",
    author="Fabien LOISON",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "yoga>=1.1.0",
        "pycairo",
        "PyGObject>=3.26",
    ],
    extras_require={
        "dev": [
            "nox",
            "flake8",
            "pytest",
            "black",
        ]
    },
    entry_points={
        "console_scripts": [
            "yoga-image-optimizer = yoga_image_optimizer.__main__:main",
        ]
    },
)
